@@ -2,7 +2,7 @@
 import json
 import requests
 import uuid
-
+from abc import ABC
 from .encryption import Encryption
 from ..exceptions.exceptions import NTCoreAPIException
 from ..__about__ import __version__
@@ -13,7 +13,7 @@ except ImportError:
     from urlparse import urljoin  # Python 2
 
 
-class ApiClient(object):
+class ApiClient(ABC):
     '''
     The NTCore API Client.
 
@@ -97,7 +97,7 @@ class ApiClient(object):
             response = self.session.request(
                 method=method,
                 url=urljoin(self.baseUrl, url),
-                data=self.__getRequestData(data),
+                data=self._getRequestData(data),
                 headers=headers,
                 params=params,
                 files=files
@@ -161,7 +161,7 @@ class ApiClient(object):
             params=params
         )
 
-    def doPost(self, partialUrl, data, headers={}):
+    def doPost(self, partialUrl, data, files=None, headers={}):
         '''
         Submit a POST to the API.
 
@@ -178,6 +178,7 @@ class ApiClient(object):
         return self._makeRequest(
             method='POST',
             url=partialUrl,
+            files=files,
             data=data,
             headers=headers
         )
@@ -227,7 +228,7 @@ class ApiClient(object):
         expectedContentType = 'application/jose+json' if self.encrypted else 'application/json'
         return response.status_code != 204 and contentType is not None and expectedContentType in contentType
 
-    def __getRequestData(self, data):
+    def _getRequestData(self, data):
         '''
         If encryption is enabled try to encrypt request data, otherwise no action required.
 
